==> nextcloud-20.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federation/l10n/eu.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Zerbitzari fidagarrien zerrendara gehituta",
    "Server is already in the list of trusted servers." : "Zerbitzaria fidagarrien zerrendan dago iada",
    "No server to federate with found" : "Ez da federatzeko zerbitzaririk topatu",
    "Could not add server" : "Ezin da zerbitzaria gehitu",
    "Federation" : "Federazioa",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "Federazioak fidagarriak diren beste zerbitzariekin erabiltzaile-direktorioa konektatzea ahalbidetzen dizu.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Federazioaren bidez fidagarriak diren zerbitzariekin erabiltzaileen direktorioa trukatzeko aukera dago. Adibidez, kanpo erabiltzaileak automatikoki betetzeko erabil daiteke, federatze partekatuan. ",
    "Trusted servers" : "Zerbitzari fidagarriak",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Federazioaren bidez fidagarriak diren zerbitzariekin erabiltzaile-direktorioa trukatzeko aukera dago. Adibidez, kanpo erabiltzaileak automatikoki betetzeko erabil daiteke, federatze partekatuan. Federatze partekatua egiteko ez da beharrezkoa zerbitzari bat gehitzea zerbitzari fidagarri gisa.",
    "Add server automatically once a federated share was created successfully" : "Zerbitzaria automatikoki gehitu federatutako partekatze bat ondo sortzen denean",
    "+ Add trusted server" : "+ Zerbitzari fidagarria gehitu",
    "Trusted server" : "Zerbitzari fidagarria",
    "Add" : "Gehitu"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-26.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/federation/l10n/eu.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Zerbitzari fidagarrien zerrendara gehituta",
    "Server is already in the list of trusted servers." : "Zerbitzaria fidagarrien zerrendan dago jadanik",
    "No server to federate with found" : "Ez da federatzeko zerbitzaririk aurkitu",
    "Could not add server" : "Ezin izan da zerbitzaria gehitu",
    "Trusted servers" : "Zerbitzari fidagarriak",
    "Federation" : "Federazioa",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "Federazioak fidagarriak diren beste zerbitzariekin erabiltzaile-direktorioa konektatzea ahalbidetzen dizu.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Federazioaren bidez fidagarriak diren zerbitzariekin erabiltzaileen direktorioa trukatzeko aukera dago. Adibidez, kanpo erabiltzaileak automatikoki betetzeko erabil daiteke, federatze partekatuan. ",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Federazioaren bidez fidagarriak diren zerbitzariekin erabiltzaile-direktorioa trukatzeko aukera dago. Adibidez, kanpo erabiltzaileak automatikoki betetzeko erabil daiteke, federatze partekatuan. Federatze partekatua egiteko ez da beharrezkoa zerbitzari bat gehitzea zerbitzari fidagarri gisa.",
    "+ Add trusted server" : "+ Gehitu zerbitzari fidagarria",
    "Trusted server" : "Zerbitzari fidagarria",
    "Add" : "Gehitu"
},
"nplurals=2; plural=(n != 1);");
